==> OpenOLAP_V1.0.zip: OpenOLAP/src/viewer/src/openolap/viewer/dao/ReportDAO.java <==
/*  OpenOlap viewer
 *  pbP[WFopenolap.viewer.dao
 *  t@CFReportDAO.java
 *  F|[gIuWFNg̉iǗC^[tF[XłB
 *
 *  쐬: 2004/01/07
 */
package openolap.viewer.dao;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;

import openolap.viewer.Report;
import openolap.viewer.common.CommonSettings;
import openolap.viewer.controller.RequestHelper;

/**
 *  C^[tF[XFReportDAO
 *  F|[gIuWFNg̉iǗC^[tF[XłB
 */
public interface ReportDAO {

	/**
	 * gp̃|[gID擾߂B
	 * @param conn ConnectionIuWFNg
	 * @return gp̃|[gID
	 * @exception SQLException ɗO
	 */
	public String getInitialReportID(Connection conn) throws SQLException;

	/**
	 * NCAg瑗MꂽftHgo[A̔zuf̃|[gIuWFNgɔfB
	 *   p[^j
	 *     defaultMembersFS̃ftHgo[
	 *     colItemsFGbWɔzuꂽID
	 *     rowItemsFsGbWɔzuꂽID
	 *     pageItemsFy[WGbWɔzuꂽID
	 * @param helper RequestHelperIuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 */
	public void registAxisPosition(RequestHelper helper, CommonSettings commonSettings);

	/**
	 * |[g̎̃GbWzuXVB
	 * @param colItemList ɔzuꂽIDXg
	 * @param rowItemList sɔzuꂽIDXg
	 * @param pageItemList y[WɔzuꂽIDXg
	 * @param report |[g킷IuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 */
	public void registAxisPosition(ArrayList colItemList, ArrayList rowItemList, ArrayList pageItemList, Report report);

	/**
	 * |[gf[^\[X֕ۑB
	 * @param report |[g킷IuWFNg
	 * @param conn ConnectionIuWFNg
	 * @exception SQLException ɗO
	 */
	public void saveReport(Report report, Connection conn) throws SQLException;

	/**
	 * L[uV[PXԍƂɁA|[gIuWFNg𐶐B
	 * @param cubeSeq L[uV[PXԍ
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 * @return |[gIuWFNg
	 * @exception SQLException ɗO
	 */
	public Report getInitialReport(String cubeSeq, CommonSettings commonSettings) throws SQLException;

	/**
	 * |[gIDƂɊ̃|[gIuWFNg߂B
	 * @param reportId |[gID
	 * @param helper RequestHelperIuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 * @return |[gIuWFNg
	 * @exception SQLException ɗO
	 */
	public Report getExistingReport(String reportId, RequestHelper helper, CommonSettings commonSettings) throws SQLException;

	/**
	 * NCAg瑗Mꂽ|[ǵ̖AetH_f̃|[gIuWFNgɔfB
	 *   p[^j
	 *     reportNameF|[g
	 *     folderIDF|[gi[tH_ID
	 * @param helper RequestHelperIuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 */
	public void registReport(RequestHelper helper, CommonSettings commonSettings);

}

==> OpenOLAP_V1.2.0.zip: OpenOLAP/src/viewer/src/openolap/viewer/dao/ReportDAO.java <==
/*  OpenOlap viewer
 *  pbP[WFopenolap.viewer.dao
 *  t@CFReportDAO.java
 *  F|[gIuWFNg̉iǗC^[tF[XłB
 *
 *  쐬: 2004/01/07
 */
package openolap.viewer.dao;

import java.sql.Connection;
import java.sql.SQLException;
import java.util.ArrayList;

import openolap.viewer.Report;
import openolap.viewer.common.CommonSettings;
import openolap.viewer.controller.RequestHelper;

/**
 *  C^[tF[XFReportDAO<br>
 *  F|[gIuWFNg̉iǗC^[tF[XłB
 */
public interface ReportDAO {

	/**
	 * gp̃|[gID擾߂B
	 * @param conn ConnectionIuWFNg
	 * @return gp̃|[gID
	 * @exception SQLException ɗO
	 */
	public String getInitialReportID(Connection conn) throws SQLException;

	/**
	 * NCAg瑗MꂽftHgo[A̔zuf̃|[gIuWFNgɔfB
	 *   p[^j
	 *     defaultMembersFS̃ftHgo[
	 *     colItemsFGbWɔzuꂽID
	 *     rowItemsFsGbWɔzuꂽID
	 *     pageItemsFy[WGbWɔzuꂽID
	 * @param helper RequestHelperIuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 */
	public void registAxisPosition(RequestHelper helper, CommonSettings commonSettings);

	/**
	 * |[g̎̃GbWzuXVB
	 * @param colItemList ɔzuꂽIDXg
	 * @param rowItemList sɔzuꂽIDXg
	 * @param pageItemList y[WɔzuꂽIDXg
	 * @param report |[g킷IuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 */
	public void registAxisPosition(ArrayList colItemList, ArrayList rowItemList, ArrayList pageItemList, Report report);

	/**
	 * |[gf[^\[X֕ۑB
	 * @param report |[g킷IuWFNg
	 * @param conn ConnectionIuWFNg
	 * @exception SQLException ɗO
	 */
	public void saveReport(Report report, Connection conn) throws SQLException;


	/**
	 * |[gf[^\[X֕ۑB
	 * @param report |[g킷IuWFNg
	 * @param newReportName VK|[g
	 * @param userID [UID
	 * @param conn ConnectionIuWFNg
	 * @exception SQLException ɗO
	 */
	public void saveNewPersonalReport(Report report, String newReportName, String userID, Connection conn)  throws SQLException;


	/**
	 * L[uV[PXԍƂɁA|[gIuWFNg𐶐B
	 * @param cubeSeq L[uV[PXԍ
	 * @param userID |[g̏L[UID 
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 * @return |[gIuWFNg
	 * @exception SQLException ɗO
	 */
	public Report getInitialReport(String cubeSeq, String userID, CommonSettings commonSettings) throws SQLException;

	/**
	 * |[gIDƂɊ̃|[gIuWFNg߂B
	 * @param reportId |[gID
	 * @param helper RequestHelperIuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 * @return |[gIuWFNg
	 * @exception SQLException ɗO
	 */
	public Report getExistingReport(String reportId, RequestHelper helper, CommonSettings commonSettings) throws SQLException;

	/**
	 * NCAg瑗Mꂽ|[ǵ̖AetH_f̃|[gIuWFNgɔfB
	 *   p[^j
	 *     reportNameF|[g
	 *     folderIDF|[gi[tH_ID
	 * @param helper RequestHelperIuWFNg
	 * @param commonSettings AvP[V̋ʐݒIuWFNg
	 */
	public void registReport(RequestHelper helper, CommonSettings commonSettings);

}
